@@ -1,6 +1,6 @@
-package Pcore::API::Dynadot v0.4.0;
+package Pcore::API::Dynadot v0.5.0;
 
-use Pcore -dist, -class, -status;
+use Pcore -dist, -class, -result;
 
 has api_key => ( is => 'ro', isa => Str, required => 1 );
 has bind_ip => ( is => 'ro', isa => Maybe [Str] );
@@ -98,7 +98,7 @@ sub search ( $self, $domains = undef, $cb = undef ) {
 
     # nothing to search
     if ( !$query_index ) {
-        $cb->( status 200, $domains_index );
+        $cb->( result 200, $domains_index );
 
         $self->{_threads}--;
 
@@ -119,7 +119,7 @@ sub search ( $self, $domains = undef, $cb = undef ) {
             my $api_res;
 
             if ( $res->status != 200 ) {
-                $api_res = status [ $res->status, $res->reason ];
+                $api_res = result [ $res->status, $res->reason ];
             }
             else {
 
@@ -131,7 +131,7 @@ sub search ( $self, $domains = undef, $cb = undef ) {
                 if ( $status ne 'ok' ) {
                     chomp $error;
 
-                    $api_res = status [ 999, $error ];
+                    $api_res = result [ 999, $error ];
                 }
                 else {
                     shift @lines;
@@ -149,7 +149,7 @@ sub search ( $self, $domains = undef, $cb = undef ) {
                         }
                     }
 
-                    $api_res = status 200, $domains_index;
+                    $api_res = result 200, $domains_index;
                 }
             }
 
